<!DOCTYPE html><html><head><meta charSet="utf-8"/><meta name="viewport" content="width=device-width, initial-scale=1, user-scalable=no"/><link rel="manifest" href="/manifest.json"><meta property="og:title" content="ChatGPT"/><meta property="og:image" content="https://openai.com/content/images/2022/11/ChatGPT.jpg"/><meta property="og:description" content="A conversational AI system that listens, learns, and challenges"/><meta property="og:url" content="https://chat.openai.com"/><title></title><meta name="next-head-count" content="8"/><link rel="apple-touch-icon" sizes="180x180" href="/apple-touch-icon.png"/><link rel="icon" type="image/png" sizes="32x32" href="/favicon-32x32.png"/><link rel="icon" type="image/png" sizes="16x16" href="/favicon-16x16.png"/><link rel="preload" href="/fonts/soehne/soehne-buch.woff2" as="font" crossorigin=""/><link rel="preload" href="/fonts/soehne/soehne-halbfett.woff2" as="font" crossorigin=""/><link rel="preload" href="/fonts/soehne/soehne-mono-buch.woff2" as="font" crossorigin=""/><link rel="preload" href="/fonts/soehne/soehne-mono-halbfett.woff2" as="font" crossorigin=""/><link rel="preload" href="/_next/static/css/0ba7ad504b2624b8.css" as="style"/><link rel="stylesheet" href="/_next/static/css/0ba7ad504b2624b8.css" data-n-g=""/><noscript data-n-css=""></noscript><script>window.__pandora_sentry={{pandora_sentry|lower}};window.__api_prefix='{{api_prefix|safe}}';</script><script defer="" nomodule="" src="/_next/static/chunks/polyfills-c67a75d1b6f99dc8.js"></script><script src="/_next/static/chunks/webpack-347e5b868a9f07a5.js" defer=""></script><script src="/_next/static/chunks/framework-e23f030857e925d4.js" defer=""></script><script src="/_next/static/chunks/main-2f10fecca4c74462.js" defer=""></script><script src="/_next/static/chunks/pages/app-16b8642aca9f7fea.js" defer=""></script><script src="/_next/static/chunks/bd26816a-981e1ddc27b37cc6.js" defer=""></script><script src="/_next/static/chunks/1f110208-cda4026aba1898fb.js" defer=""></script><script src="/_next/static/chunks/012ff928-bcfa62e3ac82441c.js" defer=""></script><script src="/_next/static/chunks/68a27ff6-a453fd719d5bf767.js" defer=""></script><script src="/_next/static/chunks/588-439179c71d396f90.js" defer=""></script><script src="/_next/static/chunks/58-107b19eac1b472e5.js" defer=""></script><script src="/_next/static/chunks/734-f1cef41ade2ec244.js" defer=""></script><script src="/_next/static/chunks/pages/index-bb8fda2bb300c73d.js" defer=""></script><script src="/_next/static/MYarkpkg17PeZHlffaxc-/buildManifest1.js" defer=""></script><script src="/_next/static/MYarkpkg17PeZHlffaxc-/ssgManifest.js" defer=""></script></head><body class="antialiased"><div id="__next"><script>!function(){try{var d=document.documentElement,c=d.classList;c.remove('light','dark');var e=localStorage.getItem('theme');if('system'===e||(!e&&true)){var t='(prefers-color-scheme: dark)',m=window.matchMedia(t);if(m.media!==t||m.matches){d.style.colorScheme = 'dark';c.add('dark')}else{d.style.colorScheme = 'light';c.add('light')}}else if(e){c.add(e|| '')}if(e==='light'||e==='dark')d.style.colorScheme=e}catch(e){}}()</script><div></div><div class="overflow-hidden w-full h-full relative flex z-0"><div class="relative flex h-full max-w-full flex-1 overflow-hidden"><div class="flex h-full max-w-full flex-1 flex-col"><main class="relative h-full w-full transition-width flex flex-col overflow-hidden items-stretch flex-1"><div class="absolute z-10 hidden flex-col gap-2 md:flex right-3 top-3"></div><div class="flex-1 overflow-hidden"></div><div class="absolute bottom-0 left-0 w-full border-t md:border-t-0 dark:border-white/20 md:border-transparent md:dark:border-transparent md:bg-vert-light-gradient bg-white dark:bg-gray-800 md:!bg-transparent dark:md:bg-vert-dark-gradient pt-2"><div class="px-3 pb-3 pt-2 text-center text-xs text-gray-600 dark:text-gray-300 md:px-4 md:pb-6 md:pt-3"><span>This service is not an official OpenAI service. Powered by <a href="https://github.com/pengzhile/pandora" target="_blank" rel="noreferrer" class="underline">Pandora</a></span></div></div></main></div></div></div><div class="absolute left-0 right-0 top-0 z-[2]"></div></div><script id="__NEXT_DATA__" type="application/json">{{props|tojson|safe}}</script><script>if('serviceWorker' in navigator){window.addEventListener('load',function(){navigator.serviceWorker.register('/service-worker.js',{scope:'/'}).then(function(reg){console.log('ServiceWorker registration successful with scope: ',reg.scope);},function(e){console.log('ServiceWorker registration failed: ',e);});});}</script></body></html>